;; Generated package description from bufferlo.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "bufferlo" "1.2.0.20260314.1104" "Frame/Tab Local Buffer Lists with Persistence" '((emacs "29.1")) :commit "b2b9bd9f59d267d223ec2b1a52d00803361b863f" :authors '(("Florian Rommel" . "mail@florommel.de") ("Stephane Marks" . "shipmints@gmail.com")) :maintainer '(("Florian Rommel" . "mail@florommel.de") ("Stephane Marks" . "shipmints@gmail.com")) :keywords '("buffer" "frame" "tabs" "local") :url "https://github.com/florommel/bufferlo")
